import * as stream from 'stream';
import getDecryptor from '../decryption/decryptChunk';

export default function decryptStream(inputStream: stream.Readable, decryptionKeys: [number, number, number]): stream.Readable {
  const decryptor = getDecryptor(decryptionKeys);

  const outStream = new stream.Readable({
    read(size) {
      //Decrypt chunk
      const encryptedChunk: Buffer = inputStream.read(size);
      if (encryptedChunk === null) {
        //If end has been reached, stop
        this.push(null);
      } else {
        const decryptedChunk = decryptor(encryptedChunk);
        this.push(decryptedChunk);
      }
    },
  });

  inputStream.on('end', () => {
    outStream.emit('end');
  });

  return outStream;
}
